==> aster-full-src-7.4.0-4.tar.gz: STA7.4/bibfor/algorith/cfimp3.f <==
      SUBROUTINE CFIMP3(DEFICO,RESOCO,NOMA,IFM,NUMORD,INSTAP,NBLIAI,
     &                  NBLIAC,JCNSVR)
C
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ALGORITH  DATE 02/11/2004   AUTEUR MABBAS M.ABBAS 
C ======================================================================
C COPYRIGHT (C) 1991 - 2004  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY  
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY  
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR     
C (AT YOUR OPTION) ANY LATER VERSION.                                   
C                                                                       
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT   
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF            
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU      
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                              
C                                                                       
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE     
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,         
C   1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.         
C ======================================================================
C
      IMPLICIT     NONE
      CHARACTER*24 DEFICO
      CHARACTER*24 RESOCO
      INTEGER      IFM
      INTEGER      NUMORD
      INTEGER      NBLIAI
      INTEGER      NBLIAC
      INTEGER      JCNSVR
      CHARACTER*8  NOMA
      REAL*8       INSTAP
C
C ----------------------------------------------------------------------
C ROUTINE APPELEE PAR : RESUCO
C ----------------------------------------------------------------------
C
C IMPRESSION DES INFOS SUR LES LIAISONS DE CONTACT/FROTTEMENT
C
C IN  IFM    : UNITE D'IMPRESSION DU MESSAGE
C IN  NOMA   : NOM DU MAILLAGE
C IN  DEFICO : SD DE DEFINITION DU CONTACT (ISSUE D'AFFE_CHAR_MECA)
C IN  RESOCO : SD DE TRAITEMENT NUMERIQUE DU CONTACT
C IN  NUMORD : NUMERO D'INSTANT
C IN  INSTAP : INSTANT DE CALCUL
C IN  NBLIAI : NOMBRE DE LIAISONS DE CONTACT POSSIBLES
C IN  NBLIAC : NOMBRE DE LIAISONS DE CONTACT ACTIVES
C IN  JCNSVR : POINTEUR SUR OBJET CHAM_NO VALE_CONT
C
C -------------- DEBUT DECLARATIONS NORMALISEES JEVEUX -----------------
C
      CHARACTER*32 JEXNUM
      INTEGER ZI
      COMMON /IVARJE/ZI(1)
      REAL*8 ZR
      COMMON /RVARJE/ZR(1)
      COMPLEX*16 ZC
      COMMON /CVARJE/ZC(1)
      LOGICAL ZL
      COMMON /LVARJE/ZL(1)
      CHARACTER*8 ZK8
      CHARACTER*16 ZK16
      CHARACTER*24 ZK24
      CHARACTER*32 ZK32
      CHARACTER*80 ZK80
      COMMON /KVARJE/ZK8(1),ZK16(1),ZK24(1),ZK32(1),ZK80(1)
C
C ---------------- FIN DECLARATIONS NORMALISEES JEVEUX -----------------
C
      INTEGER      ZAPPAR
      PARAMETER    (ZAPPAR=3)
      INTEGER      II,POSESC,NUMESC,NUMMAI,POSMAI
      CHARACTER*8  NOMESC,NOMMAI
      CHARACTER*4  TYPE2
      CHARACTER*24 APPARI,CONTNO,CONTMA,APJEU
      INTEGER      JAPPAR,JNOCO,JMACO,JAPJEU
      REAL*8       RN,R,COE,PROD,R8PREM,VARC,AJEUFT
C
C ----------------------------------------------------------------------
C

      APPARI = RESOCO(1:14)//'.APPARI'
      CONTNO = DEFICO(1:16)//'.NOEUCO'
      CONTMA = DEFICO(1:16)//'.MAILCO'
      APJEU  = RESOCO(1:14)//'.APJEU'

      CALL JEVEUO(APPARI,'L',JAPPAR)
      CALL JEVEUO(CONTNO,'L',JNOCO )
      CALL JEVEUO(CONTMA,'L',JMACO )
      CALL JEVEUO(APJEU, 'L',JAPJEU)

      WRITE(IFM,1000) 
      WRITE(IFM,1001) NUMORD
      WRITE(IFM,1002) INSTAP
      WRITE(IFM,1003) NBLIAI
      WRITE(IFM,1004) NBLIAC

      DO 120 II = 1,NBLIAI
C
C --- RECHERCHE CONNECTIVITE
C
        POSESC = ZI(JAPPAR+ZAPPAR*(II-1)+1)
        NUMESC = ZI(JNOCO+POSESC-1)
        CALL JENUNO(JEXNUM(NOMA//'.NOMNOE',NUMESC),NOMESC)
        POSMAI = ZI(JAPPAR+ZAPPAR* (II-1)+2)
C
C --- PREPARATION DES CHAINES POUR LES NOMS
C
        TYPE2 = '    '
        IF (POSMAI.GT.0) THEN
          TYPE2 ='/EL '
          NUMMAI = ZI(JMACO+POSMAI-1)
          CALL JENUNO(JEXNUM(NOMA//'.NOMMAI',NUMMAI),NOMMAI)
        ELSE IF (POSMAI.LT.0) THEN   
          TYPE2 ='/ND '
          NUMMAI = ZI(JNOCO+ABS(POSMAI)-1)
          CALL JENUNO(JEXNUM(NOMA//'.NOMNOE',NUMMAI),NOMMAI)
        END IF
C
C --- VALEURS
C
        RN = ZR(JCNSVR-1+ (NUMESC-1)*19+3 )
        R  = ZR(JCNSVR-1+ (NUMESC-1)*19+19)

        COE = 0.0D0
        IF ( RN.NE.0.D0 ) THEN
          PROD = (ABS(R)-ABS(RN))
          IF ( PROD/ABS(R).LT.-R8PREM() ) THEN
             CALL UTMESS('F','CFIMP3','NORME TANGENTIELLE
     &         DE FROTTEMENT NEGATIVE')
          ENDIF
          COE = PROD/RN
        ENDIF

        VARC   = ZR(JCNSVR-1+ (NUMESC-1)*19+1 )
        AJEUFT = ZR(JCNSVR-1+ (NUMESC-1)*19+9 )
        IF (VARC.NE.0.0D0) THEN
          WRITE (IFM,2000) II,' (ND',NOMESC,TYPE2,NOMMAI,
     &                     ') * JEU:',ZR(JAPJEU+II-1),' * RN:',RN,
     &                     ' * GLI:',AJEUFT,' * R:',R,
     &                     ' * RT/RN:',COE
        ELSE
          WRITE (IFM,2001) II,' (  ',NOMESC,TYPE2,NOMMAI,
     &                     ') * JEU:',ZR(JAPJEU+II-1),' * RN:',RN,
     &                     ' * GLI:',AJEUFT,' * R:',R,
     &                     ' * RT/RN:',COE
        ENDIF
 120  CONTINUE

 
1000  FORMAT (' <CONTACT> LISTE DES LIAISONS DE CONTACT')
1001  FORMAT (' <CONTACT>   NUMERO D''ORDRE  : ',I6)
1002  FORMAT (' <CONTACT>   INSTANT          : ',1PE12.5)
1003  FORMAT (' <CONTACT>   LIAISONS         : ',I6)
1004  FORMAT (' <CONTACT>   LIAISONS ACTIVES : ',I6)
2000  FORMAT (' <CONTACT>   * LIAISON ACTIVE   ',I6,A4,A8,A4,A8,
     &        A8,1PE12.5,A6,1PE12.5,
     &        A7,1PE12.5,A5,1PE12.5,
     &        A9,1PE12.5)
2001  FORMAT (' <CONTACT>   * LIAISON INACTIVE ',I6,A4,A8,A4,A8,
     &        A8,1PE12.5,A6,1PE12.5,
     &        A7,1PE12.5,A5,1PE12.5,
     &        A9,1PE12.5)

      END

==> aster-full-src-8.1.0-1.tar.gz: STA8.1/bibfor/algorith/cfimp3.f <==
      SUBROUTINE CFIMP3(DEFICO,RESOCO,NOMA,IFM,NUMORD,INSTAP,NBLIAI,
     &                  NBLIAC,JCNSVR)
C
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ALGORITH  DATE 04/04/2005   AUTEUR MABBAS M.ABBAS 
C ======================================================================
C COPYRIGHT (C) 1991 - 2004  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY  
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY  
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR     
C (AT YOUR OPTION) ANY LATER VERSION.                                   
C                                                                       
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT   
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF            
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU      
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                              
C                                                                       
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE     
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,         
C   1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.         
C ======================================================================
C
      IMPLICIT     NONE
      CHARACTER*24 DEFICO
      CHARACTER*24 RESOCO
      INTEGER      IFM
      INTEGER      NUMORD
      INTEGER      NBLIAI
      INTEGER      NBLIAC
      INTEGER      JCNSVR
      CHARACTER*8  NOMA
      REAL*8       INSTAP
C
C ----------------------------------------------------------------------
C ROUTINE APPELEE PAR : RESUCO
C ----------------------------------------------------------------------
C
C IMPRESSION DES INFOS SUR LES LIAISONS DE CONTACT/FROTTEMENT
C
C IN  IFM    : UNITE D'IMPRESSION DU MESSAGE
C IN  NOMA   : NOM DU MAILLAGE
C IN  DEFICO : SD DE DEFINITION DU CONTACT (ISSUE D'AFFE_CHAR_MECA)
C IN  RESOCO : SD DE TRAITEMENT NUMERIQUE DU CONTACT
C IN  NUMORD : NUMERO D'INSTANT
C IN  INSTAP : INSTANT DE CALCUL
C IN  NBLIAI : NOMBRE DE LIAISONS DE CONTACT POSSIBLES
C IN  NBLIAC : NOMBRE DE LIAISONS DE CONTACT ACTIVES
C IN  JCNSVR : POINTEUR SUR OBJET CHAM_NO VALE_CONT
C
C -------------- DEBUT DECLARATIONS NORMALISEES JEVEUX -----------------
C
      CHARACTER*32 JEXNUM
      INTEGER ZI
      COMMON /IVARJE/ZI(1)
      REAL*8 ZR
      COMMON /RVARJE/ZR(1)
      COMPLEX*16 ZC
      COMMON /CVARJE/ZC(1)
      LOGICAL ZL
      COMMON /LVARJE/ZL(1)
      CHARACTER*8 ZK8
      CHARACTER*16 ZK16
      CHARACTER*24 ZK24
      CHARACTER*32 ZK32
      CHARACTER*80 ZK80
      COMMON /KVARJE/ZK8(1),ZK16(1),ZK24(1),ZK32(1),ZK80(1)
C
C ---------------- FIN DECLARATIONS NORMALISEES JEVEUX -----------------
C
      INTEGER      ZAPPAR
      PARAMETER    (ZAPPAR=3)
      INTEGER      ZCMP
      PARAMETER    (ZCMP=19)
      INTEGER      II,POSESC,NUMESC,NUMMAI,POSMAI
      CHARACTER*8  NOMESC,NOMMAI
      CHARACTER*4  TYPE2
      CHARACTER*24 APPARI,CONTNO,CONTMA,APJEU
      INTEGER      JAPPAR,JNOCO,JMACO,JAPJEU
      REAL*8       RN,R,COE,PROD,R8PREM,VARC,AJEUFT
C
C ----------------------------------------------------------------------
C

      APPARI = RESOCO(1:14)//'.APPARI'
      CONTNO = DEFICO(1:16)//'.NOEUCO'
      CONTMA = DEFICO(1:16)//'.MAILCO'
      APJEU  = RESOCO(1:14)//'.APJEU'

      CALL JEVEUO(APPARI,'L',JAPPAR)
      CALL JEVEUO(CONTNO,'L',JNOCO )
      CALL JEVEUO(CONTMA,'L',JMACO )
      CALL JEVEUO(APJEU, 'L',JAPJEU)

      WRITE(IFM,1000) 
      WRITE(IFM,1001) NUMORD
      WRITE(IFM,1002) INSTAP
      WRITE(IFM,1003) NBLIAI
      WRITE(IFM,1004) NBLIAC

      DO 120 II = 1,NBLIAI
C
C --- RECHERCHE CONNECTIVITE
C
        POSESC = ZI(JAPPAR+ZAPPAR*(II-1)+1)
        NUMESC = ZI(JNOCO+POSESC-1)
        CALL JENUNO(JEXNUM(NOMA//'.NOMNOE',NUMESC),NOMESC)
        POSMAI = ZI(JAPPAR+ZAPPAR* (II-1)+2)
C
C --- PREPARATION DES CHAINES POUR LES NOMS
C
        TYPE2 = '    '
        IF (POSMAI.GT.0) THEN
          TYPE2 ='/EL '
          NUMMAI = ZI(JMACO+POSMAI-1)
          CALL JENUNO(JEXNUM(NOMA//'.NOMMAI',NUMMAI),NOMMAI)
        ELSE IF (POSMAI.LT.0) THEN   
          TYPE2 ='/ND '
          NUMMAI = ZI(JNOCO+ABS(POSMAI)-1)
          CALL JENUNO(JEXNUM(NOMA//'.NOMNOE',NUMMAI),NOMMAI)
        ELSE    
          TYPE2  =' NON'
          NOMMAI = ' APPARIE'
        END IF
C
C --- VALEURS
C
        RN = ZR(JCNSVR-1+ (NUMESC-1)*ZCMP+3 )
        R  = ZR(JCNSVR-1+ (NUMESC-1)*ZCMP+19)

        COE = 0.0D0
        IF ( RN.NE.0.D0 ) THEN
          PROD = (ABS(R)-ABS(RN))
          IF ( PROD/ABS(R).LT.-R8PREM() ) THEN
             CALL UTMESS('F','CFIMP3','NORME TANGENTIELLE
     &         DE FROTTEMENT NEGATIVE')
          ENDIF
          COE = PROD/RN
        ENDIF

        VARC   = ZR(JCNSVR-1+ (NUMESC-1)*ZCMP+1 )
        AJEUFT = ZR(JCNSVR-1+ (NUMESC-1)*ZCMP+9 )
        IF (VARC.NE.0.0D0) THEN
          WRITE (IFM,2000) II,' (ND ',NOMESC,TYPE2,NOMMAI,
     &                     ') * JEU:',ZR(JAPJEU+II-1),' * RN:',RN,
     &                     ' * GLI:',AJEUFT,' * R:',R,
     &                     ' * RT/RN:',COE
        ELSE
          WRITE (IFM,2001) II,' (   ',NOMESC,TYPE2,NOMMAI,
     &                     ') * JEU:',ZR(JAPJEU+II-1),' * RN:',RN,
     &                     ' * GLI:',AJEUFT,' * R:',R,
     &                     ' * RT/RN:',COE
        ENDIF
 120  CONTINUE

 
1000  FORMAT (' <CONTACT> LISTE DES LIAISONS DE CONTACT')
1001  FORMAT (' <CONTACT>   NUMERO D''ORDRE  : ',I6)
1002  FORMAT (' <CONTACT>   INSTANT          : ',1PE12.5)
1003  FORMAT (' <CONTACT>   LIAISONS         : ',I6)
1004  FORMAT (' <CONTACT>   LIAISONS ACTIVES : ',I6)
2000  FORMAT (' <CONTACT>   * LIAISON ACTIVE   ',I6,A5,A8,A4,A8,
     &        A8,1PE12.5,A6,1PE12.5,
     &        A7,1PE12.5,A5,1PE12.5,
     &        A9,1PE12.5)
2001  FORMAT (' <CONTACT>   * LIAISON INACTIVE ',I6,A5,A8,A4,A8,
     &        A8,1PE12.5,A6,1PE12.5,
     &        A7,1PE12.5,A5,1PE12.5,
     &        A9,1PE12.5)

      END
